@@ -10,13 +10,11 @@ our @EXPORT_OK = qw(
   CLEAR_IMAGE_CACHE
   CLEAR_JS_CACHE
   CLEAR_DOWNLOADS
-  CLEAR_PASSWORDS
   CLEAR_MEDIA_DEVICES
   CLEAR_DOM_QUOTA
   CLEAR_PREDICTOR_NETWORK_DATA
   CLEAR_DOM_PUSH_NOTIFICATIONS
   CLEAR_HISTORY
-  CLEAR_SESSION_HISTORY
   CLEAR_AUTH_TOKENS
   CLEAR_AUTH_CACHE
   CLEAR_PERMISSIONS
@@ -46,20 +44,18 @@ our @EXPORT_OK = qw(
 
 our %EXPORT_TAGS = ( 'all' => \@EXPORT_OK, );
 
-our $VERSION = '1.60';
+our $VERSION = '1.61';
 
 sub CLEAR_COOKIES                          { return 1 }
 sub CLEAR_NETWORK_CACHE                    { return 2 }
 sub CLEAR_IMAGE_CACHE                      { return 4 }
 sub CLEAR_JS_CACHE                         { return 8 }
 sub CLEAR_DOWNLOADS                        { return 16 }
-sub CLEAR_PASSWORDS                        { return 32 }
 sub CLEAR_MEDIA_DEVICES                    { return 64 }
 sub CLEAR_DOM_QUOTA                        { return 128 }
 sub CLEAR_PREDICTOR_NETWORK_DATA           { return 256 }
 sub CLEAR_DOM_PUSH_NOTIFICATIONS           { return 512 }
 sub CLEAR_HISTORY                          { return 1024 }
-sub CLEAR_SESSION_HISTORY                  { return 2048 }
 sub CLEAR_AUTH_TOKENS                      { return 4096 }
 sub CLEAR_AUTH_CACHE                       { return 8192 }
 sub CLEAR_SITE_PERMISSIONS                 { return 16_384 }
@@ -103,8 +99,8 @@ sub CLEAR_COOKIES_AND_SITE_DATA {
 }
 
 sub CLEAR_FORGET_ABOUT_SITE {
-    return CLEAR_HISTORY() | CLEAR_SESSION_HISTORY() | CLEAR_ALL_CACHES() |
-      CLEAR_COOKIES() | CLEAR_EME() | CLEAR_DOWNLOADS() | CLEAR_PERMISSIONS() |
+    return CLEAR_HISTORY() | CLEAR_ALL_CACHES() | CLEAR_COOKIES() |
+      CLEAR_EME() | CLEAR_DOWNLOADS() | CLEAR_PERMISSIONS() |
       CLEAR_DOM_STORAGES() | CLEAR_CONTENT_PREFERENCES() |
       CLEAR_PREDICTOR_NETWORK_DATA() | CLEAR_DOM_PUSH_NOTIFICATIONS() |
       CLEAR_CLIENT_AUTH_REMEMBER_SERVICE() | CLEAR_REPORTS() |
@@ -122,7 +118,7 @@ Firefox::Marionette::Cache - Constants to describe actions on the cache
 
 =head1 VERSION
 
-Version 1.60
+Version 1.61
 
 =head1 SYNOPSIS
 
@@ -165,10 +161,6 @@ returns the value of CLEAR_JS_CACHE, which is 1 << 3 = 8
 
 returns the value of CLEAR_DOWNLOADS, which is 1 << 4 = 16
 
-=head2 CLEAR_PASSWORDS
-
-returns the value of CLEAR_PASSWORDS, which is 1 << 5 = 32
-
 =head2 CLEAR_MEDIA_DEVICES
 
 returns the value of CLEAR_MEDIA_DEVICES, which is 1 << 6 = 64
@@ -189,10 +181,6 @@ returns the value of CLEAR_DOM_PUSH_NOTIFICATIONS, which is 1 << 9 = 512
 
 returns the value of CLEAR_HISTORY, which is 1 << 10 = 1024 (Places history)
 
-=head2 CLEAR_SESSION_HISTORY
-
-returns the value of CLEAR_SESSION_HISTORY, which is 1 << 11 = 2048
-
 =head2 CLEAR_AUTH_TOKENS
 
 returns the value of CLEAR_AUTH_TOKENS, which is 1 << 12 = 4096
@@ -291,7 +279,7 @@ returns the value of CLEAR_DOM_STORAGES, which is (L<CLEAR_DOM_QUOTA|/CLEAR_DOM_
 
 =head2 CLEAR_FORGET_ABOUT_SITE
 
-returns the value of CLEAR_FORGET_ABOUT_SITE, which is (L<CLEAR_HISTORY|/CLEAR_HISTORY> | L<CLEAR_SESSION_HISTORY|/CLEAR_SESSION_HISTORY> | L<CLEAR_ALL_CACHES|/CLEAR_ALL_CACHES> | L<CLEAR_COOKIES|/CLEAR_COOKIES> | L<CLEAR_EME|/CLEAR_EME> | L<CLEAR_DOWNLOADS|/CLEAR_DOWNLOADS> | L<CLEAR_PERMISSIONS|/CLEAR_PERMISSIONS> | L<CLEAR_DOM_STORAGES|/CLEAR_DOM_STORAGES> | L<CLEAR_CONTENT_PREFERENCES|/CLEAR_CONTENT_PREFERENCES> | L<CLEAR_PREDICTOR_NETWORK_DATA|/CLEAR_PREDICTOR_NETWORK_DATA> | L<CLEAR_DOM_PUSH_NOTIFICATIONS|/CLEAR_DOM_PUSH_NOTIFICATIONS> | L<CLEAR_CLIENT_AUTH_REMEMBER_SERVICE|/CLEAR_CLIENT_AUTH_REMEMBER_SERVICE> | L<CLEAR_REPORTS|/CLEAR_REPORTS> | L<CLEAR_CERT_EXCEPTIONS|/CLEAR_CERT_EXCEPTIONS> | L<CLEAR_CREDENTIAL_MANAGER_STATE|/CLEAR_CREDENTIAL_MANAGER_STATE> | L<CLEAR_COOKIE_BANNER_EXECUTED_RECORD|/CLEAR_COOKIE_BANNER_EXECUTED_RECORD> | L<CLEAR_FINGERPRINTING_PROTECTION_STATE|/CLEAR_FINGERPRINTING_PROTECTION_STATE>)
+returns the value of CLEAR_FORGET_ABOUT_SITE, which is (L<CLEAR_HISTORY|/CLEAR_HISTORY> | L<CLEAR_ALL_CACHES|/CLEAR_ALL_CACHES> | L<CLEAR_COOKIES|/CLEAR_COOKIES> | L<CLEAR_EME|/CLEAR_EME> | L<CLEAR_DOWNLOADS|/CLEAR_DOWNLOADS> | L<CLEAR_PERMISSIONS|/CLEAR_PERMISSIONS> | L<CLEAR_DOM_STORAGES|/CLEAR_DOM_STORAGES> | L<CLEAR_CONTENT_PREFERENCES|/CLEAR_CONTENT_PREFERENCES> | L<CLEAR_PREDICTOR_NETWORK_DATA|/CLEAR_PREDICTOR_NETWORK_DATA> | L<CLEAR_DOM_PUSH_NOTIFICATIONS|/CLEAR_DOM_PUSH_NOTIFICATIONS> | L<CLEAR_CLIENT_AUTH_REMEMBER_SERVICE|/CLEAR_CLIENT_AUTH_REMEMBER_SERVICE> | L<CLEAR_REPORTS|/CLEAR_REPORTS> | L<CLEAR_CERT_EXCEPTIONS|/CLEAR_CERT_EXCEPTIONS> | L<CLEAR_CREDENTIAL_MANAGER_STATE|/CLEAR_CREDENTIAL_MANAGER_STATE> | L<CLEAR_COOKIE_BANNER_EXECUTED_RECORD|/CLEAR_COOKIE_BANNER_EXECUTED_RECORD> | L<CLEAR_FINGERPRINTING_PROTECTION_STATE|/CLEAR_FINGERPRINTING_PROTECTION_STATE>)
 
 =head2 CLEAR_COOKIES_AND_SITE_DATA
 
