@@ -3,14 +3,14 @@ package Firefox::Marionette::Certificate;
 use strict;
 use warnings;
 
-our $VERSION = '1.60';
+our $VERSION = '1.61';
 
 sub _NUMBER_OF_MICROSECOND_DIGITS { return -6 }
 
 sub new {
-    my ( $class, $parameters ) = @_;
+    my ( $class, %parameters ) = @_;
 
-    my $self = bless { %{$parameters} }, $class;
+    my $self = bless { %parameters }, $class;
     return $self;
 }
 
@@ -179,7 +179,7 @@ Firefox::Marionette::Certificate - Represents a x509 Certificate from Firefox
 
 =head1 VERSION
 
-Version 1.60
+Version 1.61
 
 =head1 SYNOPSIS
 
